globals [migrations extinctions punishment]
patches-own [pot total-R ideal-R PopPun PopDef ActualPun population high-skill open? lastmale? Z-min Z-max Z-range res-diff per-cap-ineq]
turtles-own [skill ideal-res skill-R old-res res selfishness shared? ProbPun punisher? prestige?
  age sex F Z]

to setup
  clear-all 
  ask patches [
    sprout 10 [ 
      set skill (.4 + random-float .5) 
      set selfishness random-float 1
      set ProbPun random-float 1
      set age random 64 
      set res random 40
      ifelse random 10 >= 5 [set sex 0] [set sex 1]] 
    set population count turtles-here
    set total-R 6000
    set pcolor scale-color green total-R 0 6000]
 reset-ticks
end


to go


consume
produce
forage
share
imitate
live-or-die
migrate
procreate
tick

end

to consume   ;;resets turtle resources to 0 since storage is not included in this model - this was an alteration to the original Rogers et al. 2011 model code
  
  ask turtles [
    set old-res 0
    set old-res old-res + res
    set res 0]

end


to produce                             ;;patch procedure; if var-enviro switch is false, patches produce according to a deterministic equation; if true, patches produce 
  ask patches [                        ;;varying amounts based on a stochastic process which makes very bad years less likely than bad, which are less likely than good years
    ifelse var-enviro = false [        ;;this code is an alteration to the original Rogers et al. (2011) code
      let old-total-R 0
      let R 0
      set old-total-R total-R
      set R (.3 * old-total-R + .6 * 2000)
      if R > 2000 [set R 2000]
      set total-R old-total-R + R
      if total-R > 6000 [set total-R 6000]
    ]
    [let old-total-R 0
      let R 0
      set old-total-R total-R
      ifelse random-float .9 > .6
        [set R (.3 * old-total-R + .6 * 2000)
          if R > 2000 [set R 2000]
          set total-R old-total-R + R
          if total-R > 6000 [set total-R 6000]]
        [ifelse random-float .6 > .3
          [set R (.3 * old-total-R + .6 * 2000) * .66
            if R > 2000 [set R 2000]
            set total-R old-total-R + R
            if total-R > 6000 [set total-R 6000]]
          [set R (.3 * old-total-R + .6 * 2000) * .33
            if R > 2000 [set R 2000]
            set total-R old-total-R + R
            if total-R > 6000 [set total-R 6000]]
        ]
    ]
  ]
end


to forage                                        ;;patch procedure - patches provide resources to turtles based on their skill, unless patch resources are below
 ask patches                                     ;;the skill-based ideal for all turltes on the patch. In that case, each turtle's skill determines how much of their
    [ask turtles-here                            ;;share of the available resources they get. This code is an alteration to the original Rogers et al. 2011 code.
      [set ideal-res 100 * skill]
    set ideal-R sum [ideal-res] of turtles-here
    ifelse total-R >= ideal-R
      [ask turtles-here [set skill-R 100 * skill]]
      [ask turtles-here [set skill-R (total-R / population) * skill]]
    let total-skill-R sum [skill-R] of turtles-here
    set total-R total-R - total-skill-R
    set pcolor scale-color green total-R 0 6000]
 
    
end

to share                               ;;patch proecure; each patch calls its turtles to add resources to the pot according to the turtles selfishness variable. Those
  ask patches [                        ;;turtles that provide more than half of what they foraged are labeled as having shared; those that provide less, are labeled as having
    set pot 0                          ;;not shared. After sharing, turtles who shared have a chance to punish those who did not based on their ProbPun variable; if they 
    ask turtles-here [                 ;;do punish, they incur a pun-cost (set by slider). If any sharing turtles punished, then non-sharing turtles reduce their resources
      set res skill-R * selfishness    ;;by the pun-fraction (set by slider) and add those resources to the pot. At the end of this procedure, turtles split the communal pot
      set pot pot + (skill-R - res)    ;;equally among all. This code is an alteration to the original Rogers et al. 2011 code.
      set skill-R 0
      ifelse selfishness < .5
        [set shared? true]
        [set shared? false]]
    set PopDef count turtles-here with [shared? = false]
    set PopPun count turtles-here with [shared? = true]
    if PopDef > 0 and PopPun > 0 
      [ask turtles-here [set punisher? false]
       ask turtles-here with [shared? = true]
        [if random-float 1 < ProbPun
          [set res res - pun-cost 
            set punisher? true
            set punishment punishment + 1]
        ]
        ask turtles-here with [shared? = false]
          [if count turtles-here with [punisher? = true] > 1
            [let penalty (res * pun-fraction)
              set res res - penalty 
              set pot pot + penalty
              set selfishness selfishness - self-fraction
              if selfishness < 0 [set selfishness 0.01]
            ]
          ]
      ]
    set ActualPun count turtles-here with [punisher? = true]
    ask turtles-here  
      [set res res + (pot / count turtles-here) 
        ]
    ]
  
  
end


to imitate                                                    ;;patch procedure - identifies the turtle with the highest skill on the patch, labels that turtle "prestige?"
  ask patches [ask turtles-here [set prestige? false]]        ;; and calls all other turtles to adjust their skill and ProbPun variables to be more in line with that turtle.
  ask patches [                                               ;;This code is an alteration to the original Rogers et al. 2011 code.
    set population count turtles-here
    if population > 0 
      [let prest-self 0
        let prest-ProbPun 0
        set high-skill max [skill] of turtles-here
        ask one-of turtles-here with [skill = high-skill] 
          [set prestige? true set prest-self selfishness set prest-ProbPun ProbPun]
        ask turtles-here with [prestige? = false]
        [let skill-diff skill - high-skill
          ifelse skill-diff >= 0 
            [set skill skill - .01]
            [set skill skill + .001]
          let ProbPun-diff ProbPun - prest-ProbPun
          ifelse ProbPun-diff >= 0
            [set ProbPun ProbPun - .01]
            [set ProbPun ProbPun + .01]]
        ask turtles-here 
          [if skill > 1 [set skill .99]
            if skill < 0 [set skill .01]
            if ProbPun > 1 [set ProbPun .99]
            if ProbPun < 0 [set ProbPun .01]
          ]
      ]
  ]
  
  
    
    
    
  end


to live-or-die                                    ;;turtle procedure - turtles live or die based on the resources they acquired during foraging and sharing. survival is 
  let max-survive 0                               ;;tied to their resource level by a minimum resource level below which it is not possible; also, the Fitness Metric F 
  let low-survive 0                               ;;is calculated based on their relative position in the resource spectrum, calculated by Z-score. Turtles over 72 die.
  ask turtles [                                   ;;This code is an alteration to the original Rogers et al. 2011 code.
    ifelse count turtles-here = 1
      [set Z 0]
      [ifelse standard-deviation [res] of turtles-here = 0
        [set Z 0]
        [set Z (res - mean [res] of turtles-here)
          / standard-deviation [res] of turtles-here]
      ]
    set F 1 + (Z / 100)]
  ask turtles with [age > 71] [die]
  ask turtles [set max-survive F * Ms
    ifelse age <= 64 
      [ifelse res > 40
        [ifelse random-float 100 <= max-survive * 100
          [set age age + 1]
          [die]]
        [ifelse res > Ls
          [set low-survive F * Ms * (sqrt (1 - ((40 - res) / (40 - Ls)) ^ 2))
            ifelse random-float 100 <= low-survive * 100
              [set age age + 1]
              [die]]
          [die]]]
      [let old-age-factor 1 - (age - 65) / 8
        ifelse res > 40
          [ifelse random-float 100 <= max-survive * old-age-factor * 100
            [set age age + 1]
            [die]]
          [ifelse res > Ls
            [set low-survive F * Ms * (sqrt (1 - ((40 - res) / (40 - Ls)) ^ 2))
              ifelse random-float 100 <= low-survive * old-age-factor * 100
                [set age age + 1]
                [die]]
            [die]]]]
  ask patches [set population count turtles-here 
    ifelse population = 0 
    [set extinctions extinctions + 1]
    [ifelse population > 1
      [set Z-min min [Z] of turtles-here
        set Z-max max [Z] of turtles-here
        set Z-range Z-max - Z-min
        let min-res 0
        let max-res 0
        set min-res min [res] of turtles-here
        set max-res max [res] of turtles-here
        set res-diff max-res - min-res
        set per-cap-ineq res-diff / population]
      []
    ]
  ]
  
     
end      


to migrate                                                    ;;patch procedure - patches monitor their neighbors populations, and if a neighbor becomes vacant,
  ask patches [set population count turtles-here]             ;;the patch calls half its turtles to move onto the new patch.
  ask patches [                                               ;;This code is an alteration to the original Rogers et al. 2011 code.
    let OpenPatch 0
    if any? neighbors with [population = 0]
      [set OpenPatch one-of neighbors with [population = 0]
        ask n-of (population / 2) turtles-here
          [move-to OpenPatch
           ask patch-here [set population count turtles-here
             set migrations migrations + 1]
          ]
      ]
  ]
  
end


to procreate                          ;;turtle procedure - turtles have a chance to produce offspring based on their resource level. If resources are below a minimum value
  ask turtles with [sex = 1]          ;;they cannot give birth that year; if above that value but below optimal, their chance of giving birth is limited by their Fitness Metric
  [let max-fert 0                     ;;and resource level; if resources are optimal or above, their chance is still affected by their Fitness Metric
    let low-fert 0                    ;;This code is an alteration to the original Rogers et al. 2011 code.
    set max-fert F * Mb 
    if (age > 17) and (age < 37)
      [ifelse res >= 40
        [if random-float 1 <= max-fert
          [hatch 1 
            [set age 0 set heading random 360 set color random 256
              set skill (.4 + random-float .5) set punisher? false set prestige? false 
              ifelse lastmale? = true
                [set sex 1 set lastmale? false] [set sex 0 set lastmale? true]
            ]
          ]
        ]
        [if res > Lb
          [set low-fert F * Mb * (sqrt (1 - ((40 - res) / (40 - Lb)) ^ 2))
            if random-float 100 <= low-fert * 100
            [hatch 1 
              [set age 0 set heading random 360 set color random 256 
                set skill (.4 + random-float .5) set punisher? false set prestige? false 
                ifelse lastmale? = true
                  [set sex 1 set lastmale? false] [set sex 0 set lastmale? true]
              ]
            ]
          ]
        ]
      ]
  ]
  
  
end






  
@#$#@#$#@
GRAPHICS-WINDOW
479
10
724
206
-1
-1
33.0
1
10
1
1
1
0
0
0
1
0
4
0
4
0
0
1
ticks
30.0

BUTTON
25
10
91
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
112
11
175
44
NIL
go\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
14
137
312
287
mean res
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"res" 1.0 0 -6459832 true "" "plot mean [res] of turtles"

PLOT
17
306
313
475
turtle vars
NIL
NIL
0.0
10.0
-0.1
1.0
true
true
"" ""
PENS
"selfishness" 1.0 0 -13840069 true "" "plot mean [selfishness] of turtles"
"ProbPun" 1.0 0 -2674135 true "" "plot mean [ProbPun] of turtles"

SLIDER
12
53
184
86
Ls
Ls
20
25
24
.5
1
NIL
HORIZONTAL

SLIDER
198
54
370
87
Ms
Ms
0
1
0.998
.001
1
NIL
HORIZONTAL

PLOT
361
311
561
461
total-R
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -13840069 true "" "plot mean [total-R] of patches"

PLOT
588
317
788
467
ProbPun
NIL
NIL
0.0
1.0
0.0
10.0
true
true
"" ""
PENS
"ProbPun" 0.1 1 -16777216 true "" "histogram [ProbPun] of turtles"

PLOT
588
493
788
643
Selfishness
NIL
NIL
0.0
1.0
0.0
5.0
true
false
"" ""
PENS
"default" 0.1 1 -16777216 true "" "histogram [selfishness] of turtles"

PLOT
680
157
840
277
res of patch 0 0 
NIL
NIL
0.0
100.0
0.0
10.0
true
false
"" ""
PENS
"res" 10.0 1 -16777216 true "" "histogram [res] of turtles-on patch 0 0"

PLOT
27
491
227
641
PopPun vs PopDef
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"ActualPun" 1.0 0 -2674135 true "" "plot mean [ActualPun] of patches"
"PopDef" 1.0 0 -13840069 true "" "plot mean [PopDef] of patches"

PLOT
364
476
564
626
Population
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count turtles"

BUTTON
196
14
259
47
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
328
167
461
200
var-enviro
var-enviro
0
1
-1000

SLIDER
198
97
370
130
Mb
Mb
0
.2
0.15
.05
1
NIL
HORIZONTAL

SLIDER
10
96
182
129
Lb
Lb
0
30
22.5
.5
1
NIL
HORIZONTAL

PLOT
829
318
1029
468
Z-range
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot mean [Z-range] of patches"

SLIDER
287
18
459
51
pun-cost
pun-cost
0
10
7
1
1
NIL
HORIZONTAL

SLIDER
321
252
493
285
pun-fraction
pun-fraction
0
.5
0.25
.1
1
NIL
HORIZONTAL

SLIDER
320
211
492
244
self-fraction
self-fraction
0
.2
0
.1
1
NIL
HORIZONTAL

PLOT
849
156
1020
276
skill
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot mean [skill] of turtles"

PLOT
811
494
1012
642
selfishness
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot mean [selfishness] of turtles"

PLOT
704
10
864
130
res-diff
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot mean [res-diff] of patches"

PLOT
891
10
1071
137
per-cap-ineq
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot mean [per-cap-ineq] of patches"

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment14" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <exitCondition>count turtles = 0</exitCondition>
    <metric>mean [ProbPun] of turtles</metric>
    <metric>mean [selfishness] of turtles</metric>
    <metric>mean [res] of turtles</metric>
    <metric>mean [skill] of turtles</metric>
    <metric>count turtles</metric>
    <metric>mean [Z-range] of patches</metric>
    <metric>mean [res-diff] of patches</metric>
    <metric>mean [per-cap-ineq] of patches</metric>
    <enumeratedValueSet variable="var-enviro">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <steppedValueSet variable="self-fraction" first="0" step="0.1" last="0.2"/>
    <enumeratedValueSet variable="pun-fraction">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pun-cost">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment15" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <exitCondition>count turtles = 0</exitCondition>
    <metric>mean [ProbPun] of turtles</metric>
    <metric>mean [selfishness] of turtles</metric>
    <metric>mean [res] of turtles</metric>
    <metric>mean [skill] of turtles</metric>
    <metric>count turtles</metric>
    <metric>mean [Z-range] of patches</metric>
    <metric>mean [res-diff] of patches</metric>
    <metric>mean [per-cap-ineq] of patches</metric>
    <metric>mean [population] of patches</metric>
    <enumeratedValueSet variable="var-enviro">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="self-fraction">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pun-fraction">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pun-cost">
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
